summaryrefslogtreecommitdiffstats
path: root/krita/ui/kis_tool.h
diff options
context:
space:
mode:
Diffstat (limited to 'krita/ui/kis_tool.h')
-rw-r--r--krita/ui/kis_tool.h45
1 files changed, 23 insertions, 22 deletions
diff --git a/krita/ui/kis_tool.h b/krita/ui/kis_tool.h
index 570ec343..c8f2d349 100644
--- a/krita/ui/kis_tool.h
+++ b/krita/ui/kis_tool.h
@@ -20,8 +20,8 @@
#ifndef KIS_TOOL_H_
#define KIS_TOOL_H_
-#include <qobject.h>
-#include <qstring.h>
+#include <tqobject.h>
+#include <tqstring.h>
#include <ksharedptr.h>
#include <kaction.h>
@@ -29,11 +29,11 @@
#include "kis_shared_ptr_vector.h"
#include "kis_canvas_observer.h"
-class QCursor;
-class QEvent;
-class QKeyEvent;
-class QRect;
-class QWidget;
+class TQCursor;
+class TQEvent;
+class TQKeyEvent;
+class TQRect;
+class TQWidget;
class KActionCollection;
class KRadioAction;
class KDialog;
@@ -47,7 +47,7 @@ class KisMoveEvent;
class KisCanvasPainter;
enum enumToolType {
- TOOL_SHAPE = 0, // Geometric shapes like ellipses and lines
+ TOOL_SHAPE = 0, // Geometric tqshapes like ellipses and lines
TOOL_FREEHAND = 1, // Freehand drawing tools
TOOL_TRANSFORM = 2, // Tools that transform the layer
TOOL_FILL = 3, // Tools that fill parts of the canvas
@@ -56,19 +56,20 @@ enum enumToolType {
};
-const Q_UINT8 NUMBER_OF_TOOLTYPES = 6;
+const TQ_UINT8 NUMBER_OF_TOOLTYPES = 6;
-class KisTool : public QObject, public KisCanvasObserver, public KShared {
+class KisTool : public TQObject, public KisCanvasObserver, public KShared {
Q_OBJECT
+ TQ_OBJECT
public:
- KisTool(const QString & name);
+ KisTool(const TQString & name);
virtual ~KisTool();
public:
virtual void paint(KisCanvasPainter& gc) = 0;
- virtual void paint(KisCanvasPainter& gc, const QRect& rc) = 0;
+ virtual void paint(KisCanvasPainter& gc, const TQRect& rc) = 0;
/**
* This function is called after the creation of a tool to create the KAction corresponding
@@ -85,20 +86,20 @@ public:
virtual void move(KisMoveEvent *e) = 0;
virtual void buttonRelease(KisButtonReleaseEvent *e) = 0;
virtual void doubleClick(KisDoubleClickEvent *e) = 0;
- virtual void keyPress(QKeyEvent *e) = 0;
- virtual void keyRelease(QKeyEvent *e) = 0;
+ virtual void keyPress(TQKeyEvent *e) = 0;
+ virtual void keyRelease(TQKeyEvent *e) = 0;
- virtual QCursor cursor() = 0;
- virtual void setCursor(const QCursor& cursor) = 0;
+ virtual TQCursor cursor() = 0;
+ virtual void setCursor(const TQCursor& cursor) = 0;
/**
* This function is called to create the configuration widget of the tool.
* @param parent the parent of the widget
*/
- virtual QWidget* createOptionWidget(QWidget* parent);
+ virtual TQWidget* createOptionWidget(TQWidget* tqparent);
/**
* @return the current configuration widget.
*/
- virtual QWidget* optionWidget();
+ virtual TQWidget* optionWidget();
KRadioAction *action() const { return m_action; }
/**
@@ -108,10 +109,10 @@ public:
virtual bool wantsAutoScroll() const { return true; }
// Methods for integration with karbon-style toolbox
- virtual Q_UINT32 priority() { return 0; }
+ virtual TQ_UINT32 priority() { return 0; }
virtual enumToolType toolType() { return TOOL_FREEHAND; }
- virtual QString icon() { return m_action->icon(); }
- virtual QString quickHelp() const { return ""; }
+ virtual TQString icon() { return m_action->icon(); }
+ virtual TQString quickHelp() const { return ""; }
public slots:
/**
@@ -85,20 +86,20 @@ public:
/**
* This function is called to create the configuration widget of the tool.
- * @param parent the parent of the widget
+ * @param tqparent the tqparent of the widget
*/